==> haskell-modern-uri-0.3.6.1-141.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-modern-uri.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 modern-uri
version:              0.3.6.1
visibility:           public
id:                   modern-uri-0.3.6.1-IwjiwRk8dF03FTPer57pKX
key:                  modern-uri-0.3.6.1-IwjiwRk8dF03FTPer57pKX
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/modern-uri
synopsis:             Modern library for working with URIs
description:          Modern library for working with URIs.
category:             Text
abi:                  20b260f169e8947f527fb6fa21356b10
exposed:              True
exposed-modules:      Text.URI Text.URI.Lens Text.URI.QQ
hidden-modules:
    Text.URI.Parser.ByteString Text.URI.Parser.Text
    Text.URI.Parser.Text.Utils Text.URI.Render Text.URI.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/modern-uri-0.3.6.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/modern-uri-0.3.6.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/modern-uri-0.3.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-modern-uri
hs-libraries:         HSmodern-uri-0.3.6.1-IwjiwRk8dF03FTPer57pKX
depends:
    QuickCheck-2.15.0.1-DMgRmI5QzBCFdvvi5liF0L base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    exceptions-0.10.7 hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    megaparsec-9.7.0-Fzm61TdpQu7Cpey7aoa8J9 mtl-2.3.1
    profunctors-5.6.3-1wSzWoPhCYk2rkrLUGeSHx
    reflection-2.1.9-LtSX5qahOBWBJVCTiw5gqi
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig template-haskell-2.20.0.0
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-modern-uri/html/modern-uri.haddock
haddock-html:         /usr/share/doc/haskell-modern-uri/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-modern-uri-0.3.6.1-142-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-modern-uri.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 modern-uri
version:              0.3.6.1
visibility:           public
id:                   modern-uri-0.3.6.1-Fr6OaKthQTjHVJ2Unps2DR
key:                  modern-uri-0.3.6.1-Fr6OaKthQTjHVJ2Unps2DR
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/modern-uri
synopsis:             Modern library for working with URIs
description:          Modern library for working with URIs.
category:             Text
abi:                  1030449300389a36df9cc8965f139447
exposed:              True
exposed-modules:      Text.URI Text.URI.Lens Text.URI.QQ
hidden-modules:
    Text.URI.Parser.ByteString Text.URI.Parser.Text
    Text.URI.Parser.Text.Utils Text.URI.Render Text.URI.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/modern-uri-0.3.6.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/modern-uri-0.3.6.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/modern-uri-0.3.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-modern-uri
hs-libraries:         HSmodern-uri-0.3.6.1-Fr6OaKthQTjHVJ2Unps2DR
depends:
    QuickCheck-2.15.0.1-1xFq7rzYyJMIIsLto0YgsS base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    exceptions-0.10.7 hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    megaparsec-9.7.0-CJUMznUvVaqA9LkZfHNyDE mtl-2.3.1
    profunctors-5.6.3-11ZlnmbI5xE8sDrL55YXrn
    reflection-2.1.9-8Q7I5njAXv0HxAP0gvhFsJ
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig template-haskell-2.20.0.0
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-modern-uri/html/modern-uri.haddock
haddock-html:         /usr/share/doc/haskell-modern-uri/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
